pub struct Auto {
pub mode: Option<AutoModes>,
pub number: Option<Number>,
pub direction: Option<Direction>,
pub palette: Option<Vec<Color>>,
}Fields
mode: Option<AutoModes>The method to use for determining the solid or gradient color(s) to apply.
Default: AutoModes::Border
number: Option<Number>Relevant only when setting mode to one of the ‘gradient’ options. The number of predominant colors to select.
Default: Number::Two
direction: Option<Direction>Relevant only when setting mode to one of the ‘gradient’ options and when 2 colors are selected for the number
option. Specifies the direction to blend the 2 colors together. (If 4 colors are selected, each gets
interpolated between the four corners and this parameter is ignored.)
Default: Direction::Horizontal
palette: Option<Vec<Color>>The palette of colors to use in the border.